import { FormConfig } from "/@/components/PageSearch";
import dayjs from "dayjs"
import quarterOfYear from 'dayjs/plugin/quarterOfYear'

dayjs.extend(quarterOfYear)
const start = dayjs().startOf('month').format('YYYY-MM-DD')
const end = dayjs().endOf('month').format('YYYY-MM-DD')

const searchFormConfig: FormConfig = {
  formItems: [
    {
      field: "timer",
      type: "date_picker",
      span: 7,
      label:' 账单日期',
      defaultValue: [start, end],
      otherOptions: {
        type: "daterange",
        startProp: "start",
        endProp: "end",
        startPlaceholder: "开始时间",
        endPlaceholder: "结束时间",
        shortcuts: [
          {
            text:'本月',
            value(){
              const start = dayjs().startOf('month').format('YYYY-MM-DD')
              const end = dayjs().endOf('month').format('YYYY-MM-DD')
              return [start, end]
            }
          },
          {
            text:'上月',
            value(){
              const start = dayjs().add(-1, 'month').startOf('month').format('YYYY-MM-DD')
              const end = dayjs().add(-1, 'month').endOf('month').format('YYYY-MM-DD')
              return [start, end]
            }
          },
          {
            text:'当前季度',
            value(){
              const date = dayjs();
              const y = date.year();
              const q = date.quarter();
              const mStart = q * 3 - 2;
              const mEnd = q * 3;
              const start = dayjs(`${y}-${mStart}`).startOf('month').format('YYYY-MM-DD');
              const end = dayjs(`${y}-${mEnd}`).endOf('month').format('YYYY-MM-DD');
              return [start, end]            
            }
          },
          {
            text:'上一季度',
            value(){
              const date = dayjs();
              const y = date.year();
              const q = date.quarter();
              let start = '';
              let end = '';
             
              if (q < 2) {
                start = dayjs(`${y - 1}-${10}`)
                  .startOf('month')
                  .format('YYYY-MM-DD');
                end = dayjs(`${y - 1}-${12}`)
                  .endOf('month')
                  .format('YYYY-MM-DD');
              } else {
                const mStart = (q - 1) * 3 - 2;
                const mEnd = (q - 1) * 3;
                start = dayjs(`${y}-${mStart}`).startOf('month').format('YYYY-MM-DD');
                end = dayjs(`${y}-${mEnd}`).endOf('month').format('YYYY-MM-DD');
              }
             
              return [start, end];
            }
          },
          {
            text:'本年',
            value(){
              const start = dayjs().startOf('year').format('YYYY-MM-DD')
              const end = dayjs().endOf('year').format('YYYY-MM-DD')
              return [start, end]
            }
          }
        ]
      }
    }
  ]
};

export default searchFormConfig;
